[ Module Hierarchy | Class Hierarchy ]

# Module Hierarchy

- genshi: This package provides various means for generating and processing web markup (XML or HTML).
  - genshi.builder: Support for programmatically generating markup streams from Python code using a very simple syntax.
  - genshi.core: Core classes for markup processing.
  - genshi.filters: Implementation of a number of stream filters.
    - genshi.filters.html: Implementation of a number of stream filters.
    - genshi.filters.i18n: Directives and utilities for internationalization and localization of templates.
    - genshi.filters.transform: A filter for functional-style transformations of markup streams.
  - genshi.input: Support for constructing markup streams from files, strings, or other sources.
  - genshi.output: This module provides different kinds of serialization methods for XML event streams.
  - genshi.path: Basic support for evaluating XPath expressions against streams.
  - genshi.template: Implementation of the template engine.
    - genshi.template._ast24
    - genshi.template.ast24: Emulation of the proper abstract syntax tree API for Python 2.4.
    - genshi.template.astutil: Support classes for generating code from abstract syntax trees.
    - genshi.template.base: Basic templating functionality.
    - genshi.template.directives: Implementation of the various template directives.
    - genshi.template.eval: Support for "safe" evaluation of Python expressions.
    - genshi.template.interpolation: String interpolation routines, i.e.
    - genshi.template.loader: Template loading and caching.
    - genshi.template.markup: Markup templating engine.
    - genshi.template.plugin: Basic support for the template engine plugin API used by TurboGears and CherryPy/Buffet.
    - genshi.template.text: Plain text templating engine.
  - genshi.util: Various utility classes and functions.